/**
 * @license
 * Copyright 2023 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */

import fs from 'fs';
import path from 'path';

const SAMPLE_DIR = path.join(process.cwd(), 'samples');

export function getSortedSamples() {
  // Get file names under /samples.
  const fileNames = fs.readdirSync(SAMPLE_DIR);

  const sampleData = fileNames.map((fileName) => {
    // Use file name without extension as the ID.
    const id = fileName.replace(/\.json$/, '');
    return getSample(id);
  });

  // Sort samples by title.
  return sampleData.sort((a, b) => {
    return a.title > b.title ? 1 : a.title < b.title ? -1 : 0;
  });
}

export function getSampleIds() {
  const fileNames = fs.readdirSync(SAMPLE_DIR);
  return fileNames.map((fileName) => {
    return {
      params: {
        id: fileName.replace(/\.json$/, ''),
      },
    };
  });
}

export function getSample(id) {
  const fullPath = path.join(SAMPLE_DIR, `${id}.json`);
  const fileContents = JSON.parse(fs.readFileSync(fullPath, 'utf8'));

  return {
    id,
    ...fileContents,
  };
}
