/**
 * @license
 * Copyright 2023 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */

import Head from 'next/head';
import Link from 'next/link';

import Layout from '../components/layout';
import { getSortedSamples } from '../lib/samples';
import sharedStyles from '../styles/shared.module.css';

export default function Home({ samples }) {
  return (
    <Layout home>
      <Head>
        <title>GPT and React sample</title>
      </Head>
      <header className={sharedStyles.centered}>
        <h1>GPT and React</h1>
      </header>
      <section className={sharedStyles.centered}>
        <p>
          This site serves as a basic example of using Google Publisher Tag with{' '}
          <a href="https://react.dev/">React</a> and{' '}
          <a href="https://nextjs.org/">Next.js</a>.
        </p>
        <p>
          The links below lead to pages that load various types of sample ads.
        </p>
      </section>
      <section>
        <h2>Samples</h2>
        <ul>
          {samples.map(({ id, title, description }) => (
            <li key={id}>
              <Link href={`/samples/${id}`}>{title}</Link> - {description}
              <br />
            </li>
          ))}
        </ul>
      </section>
    </Layout>
  );
}

export async function getStaticProps() {
  const samples = getSortedSamples();
  return {
    props: {
      samples,
    },
  };
}
