/**
 * @license
 * Copyright 2023 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */

import Head from 'next/head';

import {
  DefineAdSlot,
  RequestAds,
} from '../../components/google-publisher-tag';
import Layout from '../../components/layout';
import { getSample, getSampleIds } from '../../lib/samples';
import sharedStyles from '../../styles/shared.module.css';

export default function Sample({ sample }) {
  return (
    <Layout>
      <Head>
        <title>{sample.title}</title>
      </Head>
      <section className={sharedStyles.centered}>
        {sample.slots.map((slot, i) => (
          <DefineAdSlot adUnit={slot.adUnit} size={slot.size} key={i} />
        ))}
      </section>
      <section>
        <aside className={`${sharedStyles.callout} ${sharedStyles.centered}`}>
          <p className={sharedStyles.condensed}>
            Some samples may not work when loaded in an iframe.
          </p>
          <p className={sharedStyles.condensed}>
            If a sample fails to load, try opening the preview in a new tab.
          </p>
        </aside>
      </section>
      <RequestAds />
    </Layout>
  );
}

export async function getStaticPaths() {
  const paths = getSampleIds();
  return {
    paths,
    fallback: false,
  };
}

export async function getStaticProps({ params }) {
  const sample = getSample(params.id);
  return {
    props: {
      sample,
    },
  };
}
